==> ra-sdk-1.0.4.1-20200603.064959-2-sources.jar: com/xdja/ra/utils/DnUtil.java <==
package com.xdja.ra.utils;

import org.bouncycastle.asn1.ASN1Encodable;
import org.bouncycastle.asn1.pkcs.PKCSObjectIdentifiers;
import org.bouncycastle.asn1.x500.X500Name;

import javax.naming.NamingException;
import java.util.*;


/**
 * @program: ca
 * @description: TODO
 * @author: ssh
 * @create: 2019-10-22 10:31
 */
public class DnUtil {
    public static Map<String,String> DN = new HashMap<>();
    /**
     * look up table translating common symbols into their OIDS.
     */
    private static final List<String> DefaultLookUp = new ArrayList<>();
    static {
        DN.put("2.5.4.6","C");
        DN.put("2.5.4.3","CN");
        DN.put("2.5.4.7","L");
        DN.put("2.5.4.10","O");
        DN.put("2.5.4.11","OU");
        DN.put("2.5.4.8","ST");
        DN.put("0.9.2342.19200300.100.1.25","DC");
        DN.put("2.5.4.46","dnQualifier");
        DN.put("2.5.4.42","givenName");
        DN.put("2.5.4.43","initials");
        DN.put("2.5.4.4","SN");
        DN.put("2.5.4.9","street");
        DN.put("2.5.4.12","title");
        DN.put("2.5.4.20","telephoneNumber");
        DN.put("0.9.2342.19200300.100.1.1","UID");
        DN.put(PKCSObjectIdentifiers.pkcs_9_at_emailAddress.getId(),"E");

        DefaultLookUp.add(PKCSObjectIdentifiers.pkcs_9_at_emailAddress.getId() + "=");
        DefaultLookUp.add("businesscategory=");
        DefaultLookUp.add("c=");
        DefaultLookUp.add("cn=");
        DefaultLookUp.add("dc=");
        DefaultLookUp.add("description=");
        DefaultLookUp.add("destinationindicator=");
        DefaultLookUp.add("distinguishedname=");
        DefaultLookUp.add("dnqualifier=");
        DefaultLookUp.add("enhancedsearchguide=");
        DefaultLookUp.add("facsimiletelephonenumber=");
        DefaultLookUp.add("generationqualifier=");
        DefaultLookUp.add("givenname=");
        DefaultLookUp.add("houseidentifier=");
        DefaultLookUp.add("initials=");
        DefaultLookUp.add("internationalisdnnumber=");
        DefaultLookUp.add("l=");
        DefaultLookUp.add("member=");
        DefaultLookUp.add("name=");
        DefaultLookUp.add("o=");
        DefaultLookUp.add("ou=");
        DefaultLookUp.add("owner=");
        DefaultLookUp.add("physicaldeliveryofficename=");
        DefaultLookUp.add("postaladdress=");
        DefaultLookUp.add("postalcode=");
        DefaultLookUp.add("postofficebox=");
        DefaultLookUp.add("preferreddeliverymethod=");
        DefaultLookUp.add("registeredaddress=");
        DefaultLookUp.add("roleoccupant=");
        DefaultLookUp.add("searchguide=");
        DefaultLookUp.add("seealso=");
        DefaultLookUp.add("serialnumber=");
        DefaultLookUp.add("sn=");
        DefaultLookUp.add("st=");
        DefaultLookUp.add("street=");
        DefaultLookUp.add("telephonenumber=");
        DefaultLookUp.add("teletexterminalidentifier=");
        DefaultLookUp.add("telexnumber=");
        DefaultLookUp.add("title=");
        DefaultLookUp.add("uid=");
        DefaultLookUp.add("uniquemember=");
        DefaultLookUp.add("userpassword=");
        DefaultLookUp.add("x121address=");
        DefaultLookUp.add("x500uniqueidentifier=");
        DefaultLookUp.add("emailaddress=");
        DefaultLookUp.add("e=");

    }
    /**
     * 使用基于RFC4519风格的X500Name
     * @param dn
     * @return
     */
    public static X500Name getRFC4519X500Name(String dn) throws NamingException {
        dn = DnUtil.encodeDn(dn);
        return new X500Name(RFC4519StyleUpperCase.INSTANCE,dn);
    }
    public static X500Name getRFC4519X500Name(ASN1Encodable name) {
        return X500Name.getInstance(RFC4519StyleUpperCase.INSTANCE,name);
    }

    /**
     * DN转码
     * @param dnName
     * @return
     */
    public static String encodeDn(String dnName) throws NamingException {
        String[] strs = dnName.split(",");
        StringBuffer dnBuffer = new StringBuffer();

        boolean flag = true;
        for (int i=0;i<strs.length;i++) {
            boolean valueFlag = true;
            String dnSelf = strs[i];

            for (int n=0;n<DnUtil.DefaultLookUp.size();n++) {
                String dnKey = DnUtil.DefaultLookUp.get(n);
                String convertDn = dnSelf.toLowerCase().trim().replaceAll("\\s+","");
                if (convertDn.startsWith(dnKey.toLowerCase())) {
                    String[] convertDns = convertDn.split("=");
                    if (convertDns.length >=3) {
                        throw new NamingException("DN中同一个关键字中含有多个等号:" + dnSelf);
                    }
                    if (flag) {
                        flag = false;
                    } else {
                        dnBuffer.append(",");
                    }
                    dnBuffer.append(dnSelf);
                    valueFlag = false;
                    break;
                }
            }
            if (valueFlag) {
                if (dnSelf.contains("=")) {
                    throw new NamingException("DN中关键字对应的值中不能含有等号:" + dnSelf);
                }
                dnBuffer.append("\\,").append(dnSelf);
            }
        }
        return dnBuffer.toString();
    }
}

==> ra-sdk-1.0.5-20200922.061634-2-sources.jar: com/xdja/ra/utils/DnUtil.java <==
package com.xdja.ra.utils;

import org.bouncycastle.asn1.ASN1Encodable;
import org.bouncycastle.asn1.pkcs.PKCSObjectIdentifiers;
import org.bouncycastle.asn1.x500.RDN;
import org.bouncycastle.asn1.x500.X500Name;

import javax.naming.NamingException;
import java.util.*;


/**
 * @program: ca
 * @description: TODO
 * @author: ssh
 * @create: 2019-10-22 10:31
 */
public class DnUtil {
    public static Map<String,String> DN = new HashMap<>();
    /**
     * look up table translating common symbols into their OIDS.
     */
    private static final List<String> DefaultLookUp = new ArrayList<>();
    static {
        DN.put("2.5.4.6","C");
        DN.put("2.5.4.3","CN");
        DN.put("2.5.4.7","L");
        DN.put("2.5.4.10","O");
        DN.put("2.5.4.11","OU");
        DN.put("2.5.4.8","ST");
        DN.put("0.9.2342.19200300.100.1.25","DC");
        DN.put("2.5.4.46","dnQualifier");
        DN.put("2.5.4.42","givenName");
        DN.put("2.5.4.43","initials");
        DN.put("2.5.4.4","SN");
        DN.put("2.5.4.9","street");
        DN.put("2.5.4.12","title");
        DN.put("2.5.4.20","telephoneNumber");
        DN.put("0.9.2342.19200300.100.1.1","UID");
        DN.put(PKCSObjectIdentifiers.pkcs_9_at_emailAddress.getId(),"E");

        DefaultLookUp.add(PKCSObjectIdentifiers.pkcs_9_at_emailAddress.getId() + "=");
        DefaultLookUp.add("businesscategory=");
        DefaultLookUp.add("c=");
        DefaultLookUp.add("cn=");
        DefaultLookUp.add("dc=");
        DefaultLookUp.add("description=");
        DefaultLookUp.add("destinationindicator=");
        DefaultLookUp.add("distinguishedname=");
        DefaultLookUp.add("dnqualifier=");
        DefaultLookUp.add("enhancedsearchguide=");
        DefaultLookUp.add("facsimiletelephonenumber=");
        DefaultLookUp.add("generationqualifier=");
        DefaultLookUp.add("givenname=");
        DefaultLookUp.add("houseidentifier=");
        DefaultLookUp.add("initials=");
        DefaultLookUp.add("internationalisdnnumber=");
        DefaultLookUp.add("l=");
        DefaultLookUp.add("member=");
        DefaultLookUp.add("name=");
        DefaultLookUp.add("o=");
        DefaultLookUp.add("ou=");
        DefaultLookUp.add("owner=");
        DefaultLookUp.add("physicaldeliveryofficename=");
        DefaultLookUp.add("postaladdress=");
        DefaultLookUp.add("postalcode=");
        DefaultLookUp.add("postofficebox=");
        DefaultLookUp.add("preferreddeliverymethod=");
        DefaultLookUp.add("registeredaddress=");
        DefaultLookUp.add("roleoccupant=");
        DefaultLookUp.add("searchguide=");
        DefaultLookUp.add("seealso=");
        DefaultLookUp.add("serialnumber=");
        DefaultLookUp.add("sn=");
        DefaultLookUp.add("st=");
        DefaultLookUp.add("street=");
        DefaultLookUp.add("telephonenumber=");
        DefaultLookUp.add("teletexterminalidentifier=");
        DefaultLookUp.add("telexnumber=");
        DefaultLookUp.add("title=");
        DefaultLookUp.add("uid=");
        DefaultLookUp.add("uniquemember=");
        DefaultLookUp.add("userpassword=");
        DefaultLookUp.add("x121address=");
        DefaultLookUp.add("x500uniqueidentifier=");
        DefaultLookUp.add("emailaddress=");
        DefaultLookUp.add("e=");

    }
    /**
     * 使用基于RFC4519风格的X500Name
     * @param dn
     * @return
     */
    public static X500Name getRFC4519X500Name(String dn) throws NamingException {
        dn = DnUtil.encodeDn(dn);
        return new X500Name(RFC4519StyleUpperCase.INSTANCE,dn);
    }
    public static X500Name getRFC4519X500Name(ASN1Encodable name) {
        return X500Name.getInstance(RFC4519StyleUpperCase.INSTANCE,name);
    }
    /**
     * 数组反转
     *
     * @param array
     * @return
     */
    public static RDN[] reverseRdns(RDN[] array) {
        RDN[] newArray = new RDN[array.length];
        for (int i = 0; i < newArray.length; i++) {
            newArray[i] = array[array.length - i - 1];
        }
        return newArray;
    }
    /**
     * DN转码
     * @param dnName
     * @return
     */
    public static String encodeDn(String dnName) throws NamingException {
        String[] strs = dnName.split(",");
        StringBuffer dnBuffer = new StringBuffer();

        boolean flag = true;
        for (int i=0;i<strs.length;i++) {
            boolean valueFlag = true;
            String dnSelf = strs[i];

            for (int n=0;n<DnUtil.DefaultLookUp.size();n++) {
                String dnKey = DnUtil.DefaultLookUp.get(n);
                String convertDn = dnSelf.toLowerCase().trim().replaceAll("\\s+","");
                if (convertDn.startsWith(dnKey.toLowerCase())) {
                    String[] convertDns = convertDn.split("=");
                    if (convertDns.length >=3) {
                        throw new NamingException("DN中同一个关键字中含有多个等号:" + dnSelf);
                    }
                    if (flag) {
                        flag = false;
                    } else {
                        dnBuffer.append(",");
                    }
                    dnBuffer.append(dnSelf);
                    valueFlag = false;
                    break;
                }
            }
            if (valueFlag) {
                if (dnSelf.contains("=")) {
                    throw new NamingException("DN中关键字对应的值中不能含有等号:" + dnSelf);
                }
                dnBuffer.append("\\,").append(dnSelf);
            }
        }
        return dnBuffer.toString();
    }
}
